@@ -1,7 +1,7 @@
 # coding: utf8
 # Part of the bioread package for reading BIOPAC data.
 #
-# Copyright (c) 2016 Board of Regents of the University of Wisconsin System
+# Copyright (c) 2020 Board of Regents of the University of Wisconsin System
 #
 # Written Nate Vack <njvack@wisc.edu> with research from John Ollinger
 # at the Waisman Laboratory for Brain Imaging and Behavior, University of
@@ -10,7 +10,7 @@
 
 # NOTE: This file must not import anything, or it will break installation.
 
-version_tuple = (1, 0, 5)
+version_tuple = (2, 1, 0)
 version = ".".join([str(p) for p in version_tuple])
 version_description = "bioread {0}".format(version)
 
@@ -18,4 +18,4 @@ author = "Nate Vack"
 author_email = "njvack@wisc.edu"
 license = "GPL 2.0"
 copyright = "Copyright 2016 Boards of Regent of the University of Wisconsin System"  # noqa
-url = "https://github.com/njvack/bioread"
+url = "https://github.com/uwmadison-chm/bioread"
