@@ -1,13 +1,24 @@
 # coding: utf8
 # Part of the bioread package for reading BIOPAC data.
 #
-# Copyright (c) 2016 Board of Regents of the University of Wisconsin System
+# Copyright (c) 2020 Board of Regents of the University of Wisconsin System
 #
 # Written Nate Vack <njvack@wisc.edu> with research from John Ollinger
 # at the Waisman Laboratory for Brain Imaging and Behavior, University of
 # Wisconsin-Madison
 # Project home: http://github.com/njvack/bioread
 
+# flake8: noqa: E203, E231, E741, E405, E403
+
+# If I were to do this over again, I'd probably design it differently, without
+# the somewhat weird versioning structure, as well as using ctypes instead
+# of the weird StructDict thing we have.
+# But, you know what? It's not worth changing this now, unless there turns out
+# to be a compelling reason in the future.
+# But if you're ever looking to do something similar, probably don't use this as
+# a template of good code.
+
+
 from bioread.struct_dict import StructDict
 from bioread.file_revisions import *
 
@@ -288,11 +299,13 @@ class ChannelHeader(BiopacHeader):
 
     @property
     def units(self):
-        return self.data['szUnitsText'].decode(self.encoding).strip('\0')
+        return self.data['szUnitsText'].decode(
+            self.encoding, errors='ignore').strip('\0')
 
     @property
     def name(self):
-        return self.data['szCommentText'].decode(self.encoding).strip('\0')
+        return self.data['szCommentText'].decode(
+            self.encoding, errors='ignore').strip('\0')
 
     @property
     def point_count(self):
@@ -824,4 +837,4 @@ class V4MarkerItemHeader(BiopacHeader):
 
     @property
     def type_code(self):
-        return self.data['sMarkerStyle'].decode(self.encoding)
+        return self.data['sMarkerStyle'].decode(self.encoding, errors='ignore')
